{
  alsa-lib,
  at-spi2-atk,
  cairo,
  cups,
  dbus,
  dpkg,
  expat,
  fetchurl,
  gtk3,
  jre,
  lib,
  libdrm,
  libxkbcommon,
  makeWrapper,
  mesa,
  nspr,
  nss,
  pango,
  rad-maintainers,
  stdenv,
  xorg,
  ...
}:
# source_aarch64=("https://piston.feed-the-beast.com/app/ftb-app-${pkgver}-arm64.deb")
# sha256sums_aarch64=(ad1197556a187693cbc488142562a0c17144e33056f1c914950c2f1496a4c532)
stdenv.mkDerivation rec {
  pname = "ftb-app";
  version = "1.25.14";

  src = fetchurl {
    url = "https://piston.feed-the-beast.com/app/ftb-app-${version}-amd64.deb";
    sha256 = "c9e4ce43be5337d2c7f10c55412d0acc629178d4967aef88897ebad2aa241ef0";
  };

  nativeBuildInputs = [
    dpkg
    makeWrapper
  ];

  unpackPhase = ''
    runHook preUnpack

    dpkg -x $src ./ftb-app

    runHook postUnpack
  '';

  installPhase = ''
    runHook preInstall

    mkdir -p "$out"
    cp -r ftb-app/* "$out"

    # Flatten /usr and manually merge lib/ and usr/lib/, since mv refuses to.
    mv "$out"'/opt/FTB Electron App' "$out/bin"
    mv "$out/usr/"* "$out/"
    rmdir "$out/usr"
    rmdir "$out/opt"

    for f in "$out/share/applications/"*.desktop; do
       substituteInPlace "$f" \
           --replace-fail '/opt/FTB Electron App/ftb-app' "$out/bin/ftb-app"
    done

    # prevent self-upgrade with dpkg
    rm "$out/bin/resources/package-type"

    chmod +x "$out/bin/ftb-app"

    libs="${nss}/lib/libnss3.so ${nss}/lib/libnssutil3.so ${nss}/lib/libsmime3.so "
    libs+="${nspr}/lib/libnspr4.so ${dbus.lib}/lib/libdbus-1.so.3 "
    libs+="${at-spi2-atk}/lib/libatk-1.0.so.0 ${cups.lib}/lib/libcups.so.2 "
    libs+="${at-spi2-atk}/lib/libatk-bridge-2.0.so.0 "
    libs+="${libdrm}/lib/libdrm.so.2 ${gtk3}/lib/libgtk-3.so.0 "
    libs+="${pango.out}/lib/libpango-1.0.so.0 ${cairo}/lib/libcairo.so.2 "
    libs+="${xorg.libX11}/lib/libX11.so.6 ${xorg.libXext}/lib/libXext.so.6 "
    libs+="${xorg.libXcomposite}/lib/libXcomposite.so.1 "
    libs+="${xorg.libXdamage}/lib/libXdamage.so.1 "
    libs+="${xorg.libXfixes}/lib/libXfixes.so.3 ${expat}/lib/libexpat.so.1 "
    libs+="${xorg.libXrandr}/lib/libXrandr.so.2 ${mesa}/lib/libgbm.so.1 "
    libs+="${xorg.libxcb}/lib/libxcb.so.1 ${alsa-lib}/lib/libasound.so.2 "
    libs+="${libxkbcommon}/lib/libxkbcommon.so.0 "
    libs+="${at-spi2-atk}/lib/libatspi.so.0 ${xorg.libXtst}/lib/libXtst.so.6 "

    echo "$libs"


    for p in "$out/bin/ftb-app"; do
        wrapProgram "$p" \
            --set LD_PRELOAD "$libs" \
            --set NIX_REDIRECTS "/usr/share=$out/share:"'/opt/FTB Electron Application'"=$out/bin" \
            --set JAVA_HOME "${jre.home}"
            # --prefix PATH : "{lib.makeBinPath [ gzip gnutar ]}"
    done

    runHook postInstall
  '';

  meta = with lib; {
    description = "A new Modpack launcher for FTB and Curse modpacks.";
    homepage = "https://feed-the-beast.com/app";
    license = with licenses; [ lgpl21Only ];
    sourceProvenance = with sourceTypes; [ binaryNativeCode ];
    maintainers = with rad-maintainers; [ ahuston-0 ];
    platforms = [ "x86_64-linux" ];
    mainProgram = "ftb-app";
  };
}
